@@ -47,15 +47,10 @@ impl IntoIter {
     }
 
     pub fn now(&self) -> Option<EventInstance> {
+        let time = self.current_time;
         self.schedules
             .iter()
-            .filter_map(|event_schedules| {
-                event_schedules
-                    .into_iter()
-                    .fast_forward(self.current_time)
-                    .now()
-            })
-            .next()
+            .find_map(|event_schedules| event_schedules.iter().fast_forward(time).now())
     }
 }
 
@@ -67,10 +62,7 @@ impl Iterator for IntoIter {
             .schedules
             .iter()
             .filter_map(|event_schedule| {
-                event_schedule
-                    .into_iter()
-                    .fast_forward(self.current_time)
-                    .next()
+                event_schedule.iter().fast_forward(self.current_time).next()
             })
             .reduce(|event_a, event_b| {
                 if event_b.start_time < event_a.start_time {
@@ -120,6 +112,7 @@ pub enum MapMetaKind {
     WorldBosses,
     HardWorldBosses,
     LeyLineAnomaly,
+    TwistedMarionette,
     PVPTournaments,
     DryTop,
     VerdantBrink,
@@ -138,16 +131,22 @@ pub enum MapMetaKind {
     GrothmarValley,
     BjoraMarches,
     Dragonstorm,
+    Cantha,
+    SeitungProvince,
+    NewKainengCity,
+    TheEchovaldWilds,
+    DragonsEnd,
 }
 
 impl MapMetaKind {
     /// Get all the map meta keys available
-    pub fn all_keys() -> [MapMetaKind; 22] {
+    pub fn all_keys() -> [MapMetaKind; 28] {
         [
             MapMetaKind::DayAndNight,
             MapMetaKind::WorldBosses,
             MapMetaKind::HardWorldBosses,
             MapMetaKind::LeyLineAnomaly,
+            MapMetaKind::TwistedMarionette,
             MapMetaKind::PVPTournaments,
             MapMetaKind::DryTop,
             MapMetaKind::VerdantBrink,
@@ -166,6 +165,11 @@ impl MapMetaKind {
             MapMetaKind::GrothmarValley,
             MapMetaKind::BjoraMarches,
             MapMetaKind::Dragonstorm,
+            MapMetaKind::Cantha,
+            MapMetaKind::SeitungProvince,
+            MapMetaKind::NewKainengCity,
+            MapMetaKind::TheEchovaldWilds,
+            MapMetaKind::DragonsEnd,
         ]
     }
 
@@ -406,6 +410,16 @@ impl MapMetaKind {
                     },
                 ],
             },
+            MapMetaKind::TwistedMarionette => MapMeta {
+                name: "Twisted Marionette",
+                category: Category::CoreTyria,
+                schedules: vec![EventSchedule {
+                    name: "Twisted Marionette (Public)",
+                    offset: NaiveTime::from_hms(0, 0, 0),
+                    frequency: Duration::hours(2),
+                    length: Duration::minutes(20),
+                }],
+            },
             MapMetaKind::PVPTournaments => MapMeta {
                 name: "PvP Tournaments",
                 category: Category::CoreTyria,
@@ -770,6 +784,110 @@ impl MapMetaKind {
                     length: Duration::minutes(20),
                 }],
             },
+            MapMetaKind::Cantha => MapMeta {
+                name: "Cantha: Day and Night",
+                category: Category::EndOfDragons,
+                schedules: vec![
+                    EventSchedule {
+                        name: "Dawn",
+                        offset: NaiveTime::from_hms(0, 25, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(5),
+                    },
+                    EventSchedule {
+                        name: "Day",
+                        offset: NaiveTime::from_hms(0, 30, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::hours(1).add(Duration::minutes(10)),
+                    },
+                    EventSchedule {
+                        name: "Dusk",
+                        offset: NaiveTime::from_hms(1, 40, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(5),
+                    },
+                    EventSchedule {
+                        name: "Night",
+                        offset: NaiveTime::from_hms(1, 45, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(40),
+                    },
+                ],
+            },
+            MapMetaKind::SeitungProvince => MapMeta {
+                name: "Seitung Province",
+                category: Category::EndOfDragons,
+                schedules: vec![EventSchedule {
+                    name: "Aetherblade Assault",
+                    offset: NaiveTime::from_hms(1, 30, 0),
+                    frequency: Duration::hours(2),
+                    length: Duration::minutes(30),
+                }],
+            },
+            MapMetaKind::NewKainengCity => MapMeta {
+                name: "New Kaineng City",
+                category: Category::EndOfDragons,
+                schedules: vec![EventSchedule {
+                    name: "Kaineng Blackout",
+                    offset: NaiveTime::from_hms(0, 0, 0),
+                    frequency: Duration::hours(2),
+                    length: Duration::minutes(40),
+                }],
+            },
+            MapMetaKind::TheEchovaldWilds => MapMeta {
+                name: "The Echovald Wilds",
+                category: Category::EndOfDragons,
+                schedules: vec![
+                    EventSchedule {
+                        name: "Gang War",
+                        offset: NaiveTime::from_hms(0, 30, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(35),
+                    },
+                    EventSchedule {
+                        name: "Aspenwood",
+                        offset: NaiveTime::from_hms(1, 40, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(20),
+                    },
+                ],
+            },
+            MapMetaKind::DragonsEnd => MapMeta {
+                name: "Dragon's End",
+                category: Category::EndOfDragons,
+                schedules: vec![
+                    EventSchedule {
+                        name: "Jade Maw",
+                        offset: NaiveTime::from_hms(0, 5, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(8),
+                    },
+                    EventSchedule {
+                        name: "Preparations",
+                        offset: NaiveTime::from_hms(0, 13, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(32),
+                    },
+                    EventSchedule {
+                        name: "Jade Maw",
+                        offset: NaiveTime::from_hms(0, 45, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(8),
+                    },
+                    EventSchedule {
+                        name: "Preparations",
+                        offset: NaiveTime::from_hms(0, 53, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::minutes(8),
+                    },
+                    EventSchedule {
+                        name: "The Battle for the Jade Sea",
+                        offset: NaiveTime::from_hms(1, 0, 0),
+                        frequency: Duration::hours(2),
+                        length: Duration::hours(1),
+                    },
+                ],
+            },
         }
     }
 }
